#!/bin/bash

cachedir=~/.cache/rbn
cachefile=${0##*/}-$1

if [ ! -d $cachedir ]; then
    mkdir -p $cachedir
fi

if [ ! -f $cachedir/$cachefile ]; then
    touch $cachedir/$cachefile
fi

# Save current IFS
SAVEIFS=$IFS
# Change IFS to new line.
IFS=$'\n'

cacheage=$(($(date +%s) - $(stat -c '%Y' "$cachedir/$cachefile")))
if [ $cacheage -gt 1740 ] || [ ! -s $cachedir/$cachefile ]; then
    data=($(curl -s https://de.wttr.in/tuebingen\?0qnT 2>&1))
    echo ${data[0]} | cut -f1 -d, > $cachedir/$cachefile
    echo ${data[1]} | sed -E 's/^.{15}//' >> $cachedir/$cachefile
    echo ${data[2]} | sed -E 's/^.{15}//' >> $cachedir/$cachefile
fi

weather=($(cat $cachedir/$cachefile))

# Restore IFSClear
IFS=$SAVEIFS

temperature=$(echo ${weather[2]} | sed -E 's/([[:digit:]])+\.\./\1 bis /g')

#echo ${weather[1]##*,}

# https://fontawesome.com/icons?s=solid&c=weather
case $(echo ${weather[1]##*,} | tr '[:upper:]' '[:lower:]') in
"clear" | "sunny" | "sonnig" | "wolkenlos" | "klar")
    condition=""
    ;;
"partly cloudy" | "leicht bewölkt")
    condition=""
    ;;
"cloudy" | "bewölkt")
    condition=""
    ;;
"overcast" | "bedeckt")
    condition=""
    ;;
"mist" | "fog" | "freezing fog" | "nebel" | "gefrierender nebel")
    condition=""
    ;;
"patchy rain possible" | "patchy light drizzle" | "light drizzle" | "patchy light rain" | "light rain" | "light rain shower" | "rain" | "stellenweise regen möglich" | "stellenweise nieselregen" | "leichter nieselregen" | "stellenweise leichter regen" | "leichter regenfall" | "leichter regen" | "regen")
    condition=""
    ;;
"moderate rain at times" | "moderate rain" | "heavy rain at times" | "heavy rain" | "moderate or heavy rain shower" | "torrential rain shower" | "rain shower" | "stellenweise gemäßigter regen" | "gemäßigter regen" | "stellenweise starker regen" | "starker regen" | "gemäßigter oder starker regen" | "wolkenbruch")
    condition=""
    ;;
"patchy snow possible" | "patchy sleet possible" | "patchy freezing drizzle possible" | "freezing drizzle" | "heavy freezing drizzle" | "light freezing rain" | "moderate or heavy freezing rain" | "light sleet" | "ice pellets" | "light sleet showers" | "moderate or heavy sleet showers" | "stellenweise schnee möglich" | "stellenweise schneeregen möglich" | "stellenweise gefrierende nässe möglich" | "gefrierender nieselregen" | "starker gefrierender nieselregen" | "leichter gefrierender regen" | "gemäßigter oder starker gefrierender regen" | "leichter schneeregen" | "eiskörner" | "leichter schneeregen" | "gemäßigter oder starker schneeregen")
    condition=""
    ;;
"blowing snow" | "moderate or heavy sleet" | "patchy light snow" | "light snow" | "light snow showers" | "schneesturm" | "gemäßigter oder starker schneeregen" | "stellenweise leichter schneefall" | "leichter schneefall")
    condition=""
    ;;
"blizzard" | "patchy moderate snow" | "moderate snow" | "patchy heavy snow" | "heavy snow" | "moderate or heavy snow with thunder" | "moderate or heavy snow showers" | "stellenweise gemäßigter schneefall" | "gemäßigter schneefall" | "stellenweise starker schneefall" | "starker schneefall" | "gemäßigter oder starker schnefall mit gewitter" | "gemäßigter oder starker schneefall")
    condition=""
    ;;
"thundery outbreaks possible" | "patchy light rain with thunder" | "moderate or heavy rain with thunder" | "patchy light snow with thunder" | "gewitter möglich" | "stellenweise leichter regen mit gewitter" | "gemäßigter oder starker regen mit gewitter" | "stellenweise leichter schnefall mit gewitter")
    condition=""
    ;;
*)
    condition=""
    echo -e "{\"text\":\""$condition"\", \"alt\":\""${weather[0]}"\", \"tooltip\":\""${weather[0]}: $temperature ${weather[1]}"\"}"
    ;;
esac

#echo $temp $condition

echo -e "{\"text\":\""$temperature $condition"\", \"alt\":\""${weather[0]}"\", \"tooltip\":\""${weather[0]}: $temperature ${weather[1]}"\"}"
